## discord-custom-help
Making help commands easier

## Installation
`pip install discord-custom-help`

## Usage
```py
bot.load_extension('dch')
```

[Join Discord](https://discord.gg/7SaE8v2) For any kind of help